==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/awscdk/IntegrationTest.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Cloud integration tests.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.610Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.IntegrationTest")
public class IntegrationTest extends io.github.cdklabs.projen.Component {

    protected IntegrationTest(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected IntegrationTest(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public IntegrationTest(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.IntegrationTestOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Synthesizes the integration test and compares against a local copy (runs during build).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getAssertTask() {
        return software.amazon.jsii.Kernel.get(this, "assertTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Deploy the integration test and update the snapshot upon success.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDeployTask() {
        return software.amazon.jsii.Kernel.get(this, "deployTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Destroys a deployed stack.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDestroyTask() {
        return software.amazon.jsii.Kernel.get(this, "destroyTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) Just update snapshot (without deployment).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getSnapshotTask() {
        return software.amazon.jsii.Kernel.get(this, "snapshotTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The watch task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getWatchTask() {
        return software.amazon.jsii.Kernel.get(this, "watchTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.IntegrationTest}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.IntegrationTest> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.IntegrationTestOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.IntegrationTestOptions.Builder();
        }

        /**
         * (experimental) Destroy the test app after a successful deployment.
         * <p>
         * If disabled, leaves the
         * app deployed in the dev account.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param destroyAfterDeploy Destroy the test app after a successful deployment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder destroyAfterDeploy(final java.lang.Boolean destroyAfterDeploy) {
            this.options.destroyAfterDeploy(destroyAfterDeploy);
            return this;
        }

        /**
         * (experimental) AWS CDK dependency manager.
         * <p>
         * @return {@code this}
         * @param cdkDeps AWS CDK dependency manager. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkDeps(final io.github.cdklabs.projen.awscdk.AwsCdkDeps cdkDeps) {
            this.options.cdkDeps(cdkDeps);
            return this;
        }

        /**
         * (experimental) A path from the project root directory to a TypeScript file which contains the integration test app.
         * <p>
         * This is relative to the root directory of the project.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * // Example automatically generated from non-compiling source. May contain errors.
         * "test/subdir/foo.integ.ts"
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param entrypoint A path from the project root directory to a TypeScript file which contains the integration test app. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder entrypoint(final java.lang.String entrypoint) {
            this.options.entrypoint(entrypoint);
            return this;
        }

        /**
         * (experimental) The path of the tsconfig.json file to use when running integration test cdk apps.
         * <p>
         * @return {@code this}
         * @param tsconfigPath The path of the tsconfig.json file to use when running integration test cdk apps. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsconfigPath(final java.lang.String tsconfigPath) {
            this.options.tsconfigPath(tsconfigPath);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.awscdk.IntegrationTest}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.IntegrationTest build() {
            return new io.github.cdklabs.projen.awscdk.IntegrationTest(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/awscdk/IntegrationTest.java <==
package io.github.cdklabs.projen.awscdk;

/**
 * (experimental) Cloud integration tests.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.276Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.awscdk.IntegrationTest")
public class IntegrationTest extends io.github.cdklabs.projen.cdk.IntegrationTestBase {

    protected IntegrationTest(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected IntegrationTest(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public IntegrationTest(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.awscdk.IntegrationTestOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Destroy the integration test resources.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getDestroyTask() {
        return software.amazon.jsii.Kernel.get(this, "destroyTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) The watch task.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Task getWatchTask() {
        return software.amazon.jsii.Kernel.get(this, "watchTask", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Task.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.awscdk.IntegrationTest}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.awscdk.IntegrationTest> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.awscdk.IntegrationTestOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.awscdk.IntegrationTestOptions.Builder();
        }

        /**
         * (experimental) Destroy the test app after a successful deployment.
         * <p>
         * If disabled, leaves the
         * app deployed in the dev account.
         * <p>
         * Default: true
         * <p>
         * @return {@code this}
         * @param destroyAfterDeploy Destroy the test app after a successful deployment. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder destroyAfterDeploy(final java.lang.Boolean destroyAfterDeploy) {
            this.options.destroyAfterDeploy(destroyAfterDeploy);
            return this;
        }

        /**
         * (experimental) Enables path metadata, adding <code>aws:cdk:path</code>, with the defining construct's path, to the CloudFormation metadata for each synthesized resource.
         * <p>
         * Default: false
         * <p>
         * @return {@code this}
         * @param pathMetadata Enables path metadata, adding <code>aws:cdk:path</code>, with the defining construct's path, to the CloudFormation metadata for each synthesized resource. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder pathMetadata(final java.lang.Boolean pathMetadata) {
            this.options.pathMetadata(pathMetadata);
            return this;
        }

        /**
         * (experimental) A path from the project root directory to a TypeScript file which contains the integration test app.
         * <p>
         * This is relative to the root directory of the project.
         * <p>
         * Example:
         * <p>
         * <blockquote><pre>
         * "test/subdir/foo.integ.ts"
         * </pre></blockquote>
         * <p>
         * @return {@code this}
         * @param entrypoint A path from the project root directory to a TypeScript file which contains the integration test app. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder entrypoint(final java.lang.String entrypoint) {
            this.options.entrypoint(entrypoint);
            return this;
        }

        /**
         * (experimental) The path of the tsconfig.json file to use when running integration test cdk apps.
         * <p>
         * @return {@code this}
         * @param tsconfigPath The path of the tsconfig.json file to use when running integration test cdk apps. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder tsconfigPath(final java.lang.String tsconfigPath) {
            this.options.tsconfigPath(tsconfigPath);
            return this;
        }

        /**
         * (experimental) Name of the integration test.
         * <p>
         * Default: - Derived from the entrypoint filename.
         * <p>
         * @return {@code this}
         * @param name Name of the integration test. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder name(final java.lang.String name) {
            this.options.name(name);
            return this;
        }

        /**
         * (experimental) AWS CDK dependency manager.
         * <p>
         * @return {@code this}
         * @param cdkDeps AWS CDK dependency manager. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder cdkDeps(final io.github.cdklabs.projen.awscdk.AwsCdkDeps cdkDeps) {
            this.options.cdkDeps(cdkDeps);
            return this;
        }

        /**
         * (experimental) A list of stacks within the integration test to deploy/destroy.
         * <p>
         * Default: ["**"]
         * <p>
         * @return {@code this}
         * @param stacks A list of stacks within the integration test to deploy/destroy. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder stacks(final java.util.List<java.lang.String> stacks) {
            this.options.stacks(stacks);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.awscdk.IntegrationTest}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.awscdk.IntegrationTest build() {
            return new io.github.cdklabs.projen.awscdk.IntegrationTest(
                this.project,
                this.options.build()
            );
        }
    }
}
